@@ -15,7 +15,7 @@ def make_veins_project_description(veins_version, inet_versions, sumo_version, o
         "nix_packages": ["sumo" if veins_version >= "5.0" else None, "python2" if veins_version < "5.2" else None],
         "patch_commands": [
             "sed -i 's|^#!/usr/bin/env python$|#!/usr/bin/env python2|' configure" if veins_version<="4.6" else "",
-            """sed -i "s|'--no-deep-includes', ||" configure subprojects/veins_inet/configure""" if veins_version>="5.0" else "",
+            """sed -i "s|'--no-deep-includes', ||" configure subprojects/veins_inet/configure subprojects/veins_inet3/configure""" if veins_version>="5.0" else "",
         ],
         "setenv_commands": [
             'export OMNETPP_IMAGE_PATH="$OMNETPP_IMAGE_PATH:$VEINS_ROOT/images:$INET_ROOT/images"',
@@ -30,10 +30,10 @@ def make_veins_project_description(veins_version, inet_versions, sumo_version, o
             "echo 'Starting sumo-launchd.py'",
             """./sumo-launchd.py & bg_pid=$!""",
             "echo 'sumo PID is ' $bg_pid",
-            """trap "echo 'Stopping sumo-launchd.py at ' $bg_pid && kill $bg_pid" RETURN SIGINT SIGTERM""",
+            """trap "echo 'Stopping sumo-launchd.py at ' $bg_pid && kill $bg_pid" RETURN SIGINT SIGTERM EXIT""",
             "cd examples/veins && ./run $DEBUG_POSTFIX -c Default -u Cmdenv",
             "export VEINS_INET_INI_CONFIG='-c plain'" if veins_version >= "5.1" else "",
-            """if [[ ! ($OMNETPP_VERSION < '6.0.0') ]]; then export FIX_FOR_VEINS_5_3=' --allow-object-stealing-on-deletion=true'; fi""" if veins_version == "5.3" else "",
+            """if [[ ! ($OMNETPP_VERSION < '6.0.0') ]]; then export FIX_FOR_VEINS_5_3=' --allow-object-stealing-on-deletion=true'; fi""" if veins_version.startswith("5.3") else "",
             "if [[ ! ($INET_VERSION < '4.0.0') ]]; then cd ../../subprojects/veins_inet/examples/veins_inet && ./run $DEBUG_POSTFIX $VEINS_INET_INI_CONFIG -u Cmdenv; else cd ../../subprojects/veins_inet3/examples/veins_inet && ./run $DEBUG_POSTFIX $FIX_FOR_VEINS_5_3 -u Cmdenv; fi",
             "echo 'Stopping sumo-launchd.py at ' $bg_pid && kill $bg_pid",
         ] if veins_version >= "5.0" else ["echo 'Skipping test because required sumo version is not available as a nix package.'"],
@@ -73,6 +73,7 @@ def get_project_descriptions():
         # - many Veins versions may actually compile/work with more omnetpp versions than listed -- this is to be checked
         # - versions before 5.0 need older versions of SUMO, which are currently not available as nix packages
         # - removed omnetpp-5.5.0 from all versions due to segfault in smoke test
+        ["5.3.1", ["4.5.4", "4.5.2", "4.5.1", "4.5.0", "4.4.2", "4.4.1", "4.4.0", "3.8.3", "3.7.1", "3.7.0", "3.6.8", "3.6.7", "3.6.6", "3.6.5"], ["1.21.0"], ["6.1.*", "6.0.*", "5.7.*", "5.6.*", "5.5.2", "5.5.1", "5.4.*", "5.3.*"]],
         ["5.3", ["4.5.4", "4.5.2", "4.5.1", "4.5.0", "4.4.2", "4.4.1", "4.4.0", "3.8.3", "3.7.1", "3.7.0", "3.6.8", "3.6.7", "3.6.6", "3.6.5"], ["1.21.0"], ["6.1.*", "6.0.*", "5.7.*", "5.6.*", "5.5.2", "5.5.1", "5.4.*", "5.3.*"]],
         # note for 5.3:
         # removed inet-4.2.*/4.3.* due to subproject build errors
@@ -82,7 +83,7 @@ def get_project_descriptions():
         # removed inet-3.8.2/3.8.1: veinsinet3 error; needs 'All: Changed initial values of simtime_t fields to -1 instead of NaN.' commit to fix, which is in 3.8.3
         ["5.2", ["4.2.8", "4.2.5", "4.2.4", "4.2.3", "4.2.2", "4.2.1", "4.2.0", "3.8.1", "3.7.1", "3.7.0", "3.6.8", "3.6.7", "3.6.6", "3.6.5"], ["1.9.2"], ["5.7.*", "5.6.*", "5.5.2", "5.5.1", "5.4.*", "5.3.*"]],
         # note for 5.2:
-        ["5.1", ["4.2.1", "4.2.0", "3.6.5", "3.6.6", "3.6.7", "3.6.8"], ["1.9.2"], ["5.5.2", "5.5.1", "5.4.*", "5.3.*"]],
+        ["5.1", ["4.2.8", "4.2.5", "4.2.4", "4.2.3", "4.2.2", "4.2.1", "4.2.0", "3.6.5", "3.6.6", "3.6.7", "3.6.8"], ["1.9.2"], ["5.7.*", "5.6.*", "5.5.2", "5.5.1", "5.4.*", "5.3.*"]],
         # note for 5.1:
         ["5.0", ["4.1.1", "4.1.0", "3.6.5"], ["1.9.2"], ["5.5.2", "5.5.1", "5.4.*", "5.3.*"]],      # this is the first one that works with sumo 1.9.2
         ["4.7.1", ["3.6.0", "3.5.0", "3.4.0"], ["0.30.0"], ["5.3.*", "5.2.*", "5.1.*"]],    # needs SUMO 0.30.0
